@@ -5,18 +5,42 @@ Configuration = {
     "trace_auto_normalize_enabled": True,
     "trace_user_enabled": True,
     "trace_user_using_ip": True,
+
+    "query_string_enabled": False,
+    "query_string_urls": "",
+
     "profile_dbc_close": False,
     "profile_http_header_enabled": False,
-    
+    "profile_http_parameter_enabled": False,
+    "profile_sql_param_enabled": False,
     "hook_method_patterns": "",
-    
+
     "mtid": 0,
     "httpc_checked": True,
     "mtrace_rate": 0,
+    "mtrace_spec": '',
+    "mtrace_send_url_length": 80,
+
     "_trace_mtrace_caller_key": "x-wtap-mst",
     "_trace_mtrace_callee_key": "x-wtap-tx",
+    "_trace_mtrace_info_key": "x-wtap-inf",
     "_trace_mtrace_ip": "x-wtap-ip",
 
+    "stat_enabled": False,
+    "stat_domain_enabled": False,
+    "stat_domain_max_count": 7000,
+    "stat_mtrace_enabled": False,
+    "stat_mtrace_max_count": 7000,
+    "stat_login_enabled": False,
+    "stat_login_max_count": 7000,
+    "stat_referer_enabled": False,
+    "stat_referer_max_count": 7000,
+
+	"stat_tx_max_count": 5000,
+	"stat_sql_max_count": 5000,
+	"stat_httpc_max_count": 5000,
+	"stat_error_max_count": 1000,
+	"stat_useragent_max_count": 500,
 
     # "whatap_server_host": "127.0.0.1/127.0.0.1",
     # "whatap_server_port": 6600,
